@@ -1,23 +1,25 @@
 from webthing import (SingleThing, Property, Thing, Value, WebThingServer)
+from pi_lightsensor_webthing.lightsensor import LightSensor
 import logging
-import RPi.GPIO as GPIO
 import tornado.ioloop
 
 
-class LightSensor(Thing):
+class LightSensorThing(Thing):
 
     # regarding capabilities refer https://iot.mozilla.org/schemas
     # there is also another schema registry http://iotschema.org/docs/full.html not used by webthing
 
-    def __init__(self, gpio_number, name, description):
+    def __init__(self, description: str, light_sensor: LightSensor):
         Thing.__init__(
             self,
             'urn:dev:ops:illuminanceSensor-1',
-            'Illuminance ' + name + ' Sensor',
+            'Illuminance Sensor',
             ['MultiLevelSensor'],
             description
         )
 
+        light_sensor.listen(self.on_measured)
+
         self.bright = Value(0)
         self.add_property(
             Property(self,
@@ -27,33 +29,22 @@ class LightSensor(Thing):
                          '@type': 'BrightnessProperty',
                          'title': 'Brightness',
                          "type": "integer",
-                         'minimum': 0,
-                         'maximum': 100,
-                         'unit': 'percent',
-                         'description': '"The level of light from 0-100',
+                         'unit': 'lux',
+                         'description': '"The brightness level in lux',
                          'readOnly': True,
                      }))
 
         self.ioloop = tornado.ioloop.IOLoop.current()
-        logging.info('bind to gpio ' + str(gpio_number))
-        GPIO.setmode(GPIO.BCM)
-        GPIO.setup(gpio_number, GPIO.IN)
-        GPIO.add_event_detect(gpio_number, GPIO.BOTH, callback=self.__update, bouncetime=5)
-        self.__update(gpio_number)
 
-    def __update(self, gpio_number):
-        if GPIO.input(gpio_number):
-            self.ioloop.add_callback(self.__update_bright_prop, 0)
-        else:
-            self.ioloop.add_callback(self.__update_bright_prop, 100)
+    def on_measured(self, brightness: float):
+        self.ioloop.add_callback(self.__update_brightness, brightness)
 
-    def __update_bright_prop(self, brightness: int):
-        self.bright.notify_of_external_update(brightness)
-        logging.info("brightness: " + str(brightness))
+    def __update_brightness(self, brightness: float):
+        self.bright.notify_of_external_update(int(brightness))
 
 
-def run_server(port: int, gpio_number: int, name: str, description: str):
-    light_sensor = LightSensor(gpio_number, name, description)
+def run_server(port: int, description: str = ""):
+    light_sensor = LightSensorThing(description, LightSensor())
     server = WebThingServer(SingleThing(light_sensor), port=port, disable_host_validation=True)
     try:
         logging.info('starting the server')
